/* font.h: Prototypes and declarations for font.h
 * Copyright (C) 2020 Andreas Schiffler
 *
 * This is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MAZEWAR_FONT_H
#define MAZEWAR_FONT_H

/* The 8x13 font, in the form of a single bitmap in a packed PBM-like 
   format. */

extern unsigned char mazewar_font_8x13_bytes[2912];

#endif /* MAZEWAR_FONT_H */
